@@ -18,6 +18,7 @@ r'''
     * [Error Handling](#error-handling)
     * [Code Examples](#code-examples)
   * [Additional Information](#additional-information)
+  * [AWS SigV4 Headers](#aws-sigv4-headers)
 
 A CDK construct that creates an AWS Lambda Function acting as a transparent proxy to your Tailscale network.
 
@@ -92,7 +93,8 @@ export class MyStack extends cdk.Stack {
       //   lambda: {
       //     functionName: "tailscale-proxy",
       //   }
-      // }
+      // },
+      // debug: true, // Enable debug logging, show request + response, search for lines starting with "[tailscale-"
     });
 
     const caller = new NodejsFunction(this, "tailscale-caller", {
@@ -138,9 +140,29 @@ When calling the Proxy, include the following headers to specify the target mach
 * `ts-target-port`: The port of the Tailscale-connected machine/device.
 * `ts-https`: OPTIONAL, if undefined, the default behaviour is to use https when the port is 443. If specified then it
   will override the default behaviour.
+* See the remaining AWS SigV4 headers in the next section (special case for `Authorization`).
 
 These `ts-` headers are removed before the request is forwarded to the target machine.
 
+#### AWS SigV4 Headers
+
+The proxy automatically removes AWS SigV4 headers from the incoming request and replaces them with their `ts-`
+prefixed counterparts when forwarding the request if they exist. This allows you to forward headers that
+are named the same as required by the AWS SigV4 signature request.
+
+The following headers are handled:
+
+* `ts-authorization` → `Authorization`
+* `ts-x-amz-date` → `x-amz-date`
+* `ts-host` → `host`
+* `ts-x-amz-content-sha256` → `x-amz-content-sha256`
+
+This is useful when you need to include an `Authorization` header in the request to the target machine. If
+you place the value directly in the `Authorization` header, it will be overwritten by the AWS SigV4 signature
+that the caller generates. Instead, place your authorization value in the `ts-authorization` header. The
+proxy will remove all `ts-` prefixed headers before forwarding the request and will correctly set the
+`ts-authorization` value as the `Authorization` header in the forwarded request.
+
 ### Creating CloudWatch Tracking Metrics
 
 To enable optional tracking metrics, add the following headers to your request:
@@ -273,6 +295,7 @@ class TailscaleLambdaProxy(
         *,
         ts_hostname: builtins.str,
         ts_secret_api_key: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+        debug: typing.Optional[builtins.bool] = None,
         options: typing.Optional[typing.Union["TailscaleLambdaProxyPropsOptions", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
@@ -280,6 +303,7 @@ class TailscaleLambdaProxy(
         :param id: -
         :param ts_hostname: The "Machine" name as shown in the Tailscale admin console that identifies the Lambda function.
         :param ts_secret_api_key: The name of the AWS Secrets Manager secret that contains the pure text Tailscale API Key.
+        :param debug: 
         :param options: 
         '''
         if __debug__:
@@ -289,6 +313,7 @@ class TailscaleLambdaProxy(
         props = TailscaleLambdaProxyProps(
             ts_hostname=ts_hostname,
             ts_secret_api_key=ts_secret_api_key,
+            debug=debug,
             options=options,
         )
 
@@ -318,6 +343,7 @@ class TailscaleLambdaProxy(
     name_mapping={
         "ts_hostname": "tsHostname",
         "ts_secret_api_key": "tsSecretApiKey",
+        "debug": "debug",
         "options": "options",
     },
 )
@@ -327,11 +353,13 @@ class TailscaleLambdaProxyProps:
         *,
         ts_hostname: builtins.str,
         ts_secret_api_key: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+        debug: typing.Optional[builtins.bool] = None,
         options: typing.Optional[typing.Union["TailscaleLambdaProxyPropsOptions", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param ts_hostname: The "Machine" name as shown in the Tailscale admin console that identifies the Lambda function.
         :param ts_secret_api_key: The name of the AWS Secrets Manager secret that contains the pure text Tailscale API Key.
+        :param debug: 
         :param options: 
         '''
         if isinstance(options, dict):
@@ -340,11 +368,14 @@ class TailscaleLambdaProxyProps:
             type_hints = typing.get_type_hints(_typecheckingstub__b1db2d7dac4f0d91262bca503b92335b2c7da889dea02a4605b962b6c445b4e3)
             check_type(argname="argument ts_hostname", value=ts_hostname, expected_type=type_hints["ts_hostname"])
             check_type(argname="argument ts_secret_api_key", value=ts_secret_api_key, expected_type=type_hints["ts_secret_api_key"])
+            check_type(argname="argument debug", value=debug, expected_type=type_hints["debug"])
             check_type(argname="argument options", value=options, expected_type=type_hints["options"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "ts_hostname": ts_hostname,
             "ts_secret_api_key": ts_secret_api_key,
         }
+        if debug is not None:
+            self._values["debug"] = debug
         if options is not None:
             self._values["options"] = options
 
@@ -362,6 +393,11 @@ class TailscaleLambdaProxyProps:
         assert result is not None, "Required property 'ts_secret_api_key' is missing"
         return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.ISecret, result)
 
+    @builtins.property
+    def debug(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("debug")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def options(self) -> typing.Optional["TailscaleLambdaProxyPropsOptions"]:
         result = self._values.get("options")
@@ -499,6 +535,7 @@ def _typecheckingstub__526fa7750b0e7b9422bb864d1636199d3eb6a8950c9fbe1a2634e109e
     *,
     ts_hostname: builtins.str,
     ts_secret_api_key: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    debug: typing.Optional[builtins.bool] = None,
     options: typing.Optional[typing.Union[TailscaleLambdaProxyPropsOptions, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -508,6 +545,7 @@ def _typecheckingstub__b1db2d7dac4f0d91262bca503b92335b2c7da889dea02a4605b962b6c
     *,
     ts_hostname: builtins.str,
     ts_secret_api_key: _aws_cdk_aws_secretsmanager_ceddda9d.ISecret,
+    debug: typing.Optional[builtins.bool] = None,
     options: typing.Optional[typing.Union[TailscaleLambdaProxyPropsOptions, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
